pub enum ExternalRequest {
WaitForActivation {
hash: H256,
response_channel: Sender<Result<(), SubsystemError>>,
},
}Expand description
Some request from outer world.
Variants
WaitForActivation
Fields

hash: H256The relay parent for which activation to wait for.

response_channel: Sender<Result<(), SubsystemError>>Response channel to await on.
Wait for the activation of a particular hash and be notified by means of the return channel.