Enum polkadot_node_subsystem::SubsystemError [−][src]
pub enum SubsystemError {
NotifyCancellation(Canceled),
QueueError(SendError),
Io(Error),
Infallible(Infallible),
Prometheus(Error),
Jaeger(JaegerError),
Context(String),
SubsystemStalled(&'static str),
Generated(OverseerError),
FromOrigin {
origin: &'static str,
source: Box<dyn Error + Sync + Send + 'static, Global>,
},
}Expand description
An error type that describes faults that may happen
These are:
- Channels being closed
- Subsystems dying when they are not expected to
- Subsystems not dying when they are told to die
- etc.
Variants
NotifyCancellation(Canceled)Tuple Fields of NotifyCancellation
0: CanceledQueueError(SendError)Tuple Fields of QueueError
0: SendErrorIo(Error)Tuple Fields of Io
0: ErrorInfallible(Infallible)Tuple Fields of Infallible
0: InfalliblePrometheus(Error)Tuple Fields of Prometheus
0: ErrorJaeger(JaegerError)Tuple Fields of Jaeger
0: JaegerErrorContext(String)Tuple Fields of Context
0: StringSubsystemStalled(&'static str)Tuple Fields of SubsystemStalled
0: &'static strGenerated(OverseerError)Generated by the #[overseer(..)] proc-macro
Tuple Fields of Generated
Per origin (or subsystem) annotations to wrap an error.
Fields of FromOrigin
Implementations
pub fn with_origin<E>(origin: &'static str, err: E) -> SubsystemError where
E: 'static + Send + Sync + Error,
pub fn with_origin<E>(origin: &'static str, err: E) -> SubsystemError where
E: 'static + Send + Sync + Error,
Adds a str as origin to the given error err.