pub enum ToOrchestra {
SpawnJob {
name: &'static str,
subsystem: Option<&'static str>,
s: Pin<Box<dyn Future<Output = ()> + Send, Global>>,
},
SpawnBlockingJob {
name: &'static str,
subsystem: Option<&'static str>,
s: Pin<Box<dyn Future<Output = ()> + Send, Global>>,
},
}Expand description
A type of messages that are sent from a Subsystem to the declared orchestra.
Used to launch jobs.
Variants
SpawnJob
Fields
A message that wraps something the Subsystem is desiring to
spawn on the orchestra and a oneshot::Sender to signal the result
of the spawn.
SpawnBlockingJob
Fields
Same as SpawnJob but for blocking tasks to be executed on a
dedicated thread pool.