Enum polkadot_node_subsystem::messages::AvailabilityStoreMessage [−][src]
pub enum AvailabilityStoreMessage {
QueryAvailableData(CandidateHash, Sender<Option<AvailableData>>),
QueryDataAvailability(CandidateHash, Sender<bool>),
QueryChunk(CandidateHash, ValidatorIndex, Sender<Option<ErasureChunk>>),
QueryAllChunks(CandidateHash, Sender<Vec<ErasureChunk, Global>>),
QueryChunkAvailability(CandidateHash, ValidatorIndex, Sender<bool>),
StoreChunk {
candidate_hash: CandidateHash,
chunk: ErasureChunk,
tx: Sender<Result<(), ()>>,
},
StoreAvailableData {
candidate_hash: CandidateHash,
n_validators: u32,
available_data: AvailableData,
tx: Sender<Result<(), ()>>,
},
}Expand description
Availability store subsystem message.
Variants
QueryAvailableData(CandidateHash, Sender<Option<AvailableData>>)Query a AvailableData from the AV store.
Tuple Fields of QueryAvailableData
0: CandidateHash1: Sender<Option<AvailableData>>QueryDataAvailability(CandidateHash, Sender<bool>)Query whether a AvailableData exists within the AV Store.
This is useful in cases when existence matters, but we don’t want to necessarily pass around multiple megabytes of data to get a single bit of information.
Tuple Fields of QueryDataAvailability
0: CandidateHash1: Sender<bool>QueryChunk(CandidateHash, ValidatorIndex, Sender<Option<ErasureChunk>>)Query an ErasureChunk from the AV store by the candidate hash and validator index.
Tuple Fields of QueryChunk
QueryAllChunks(CandidateHash, Sender<Vec<ErasureChunk, Global>>)Query all chunks that we have for the given candidate hash.
Tuple Fields of QueryAllChunks
0: CandidateHash1: Sender<Vec<ErasureChunk, Global>>QueryChunkAvailability(CandidateHash, ValidatorIndex, Sender<bool>)Query whether an ErasureChunk exists within the AV Store.
This is useful in cases like bitfield signing, when existence matters, but we don’t want to necessarily pass around large quantities of data to get a single bit of information.
Tuple Fields of QueryChunkAvailability
Store an ErasureChunk in the AV store.
Return Ok(()) if the store operation succeeded, Err(()) if it failed.
Fields of StoreChunk
candidate_hash: CandidateHashA hash of the candidate this chunk belongs to.
chunk: ErasureChunkThe chunk itself.
tx: Sender<Result<(), ()>>Sending side of the channel to send result to.
Store a AvailableData and all of its chunks in the AV store.
Return Ok(()) if the store operation succeeded, Err(()) if it failed.
Fields of StoreAvailableData
candidate_hash: CandidateHashA hash of the candidate this available_data belongs to.
n_validators: u32The number of validators in the session.
available_data: AvailableDataThe AvailableData itself.
tx: Sender<Result<(), ()>>Sending side of the channel to send result to.
Implementations
In fact, none of the AvailabilityStore messages assume a particular relay parent.