pub enum CandidateBackingMessage {
GetBackedCandidates(Vec<(CandidateHash, H256)>, Sender<Vec<BackedCandidate>>),
CanSecond(CanSecondRequest, Sender<bool>),
Second(H256, CandidateReceipt, PersistedValidationData, PoV),
Statement(H256, Signed<StatementWithPVD, CompactStatement>),
}Expand description
Messages received by the Candidate Backing subsystem.
Variants
GetBackedCandidates(Vec<(CandidateHash, H256)>, Sender<Vec<BackedCandidate>>)
Requests a set of backable candidates attested by the subsystem.
Each pair is (candidate_hash, candidate_relay_parent).
CanSecond(CanSecondRequest, Sender<bool>)
Request the subsystem to check whether it’s allowed to second given candidate. The rule is to only fetch collations that are either built on top of the root of some fragment tree or have a parent node which represents backed candidate.
Always responses with false if async backing is disabled for candidate’s relay
parent.
Second(H256, CandidateReceipt, PersistedValidationData, PoV)
Note that the Candidate Backing subsystem should second the given candidate in the context of the given relay-parent (ref. by hash). This candidate must be validated.
Statement(H256, Signed<StatementWithPVD, CompactStatement>)
Note a validator’s statement about a particular candidate in the context of the given relay-parent. Disagreements about validity must be escalated to a broader check by the Disputes Subsystem, though that escalation is deferred until the approval voting stage to guarantee availability. Agreements are simply tallied until a quorum is reached.