pub enum ChainSelectionMessage {
Approved(H256),
Leaves(Sender<Vec<H256>>),
BestLeafContaining(H256, Sender<Option<H256>>),
RevertBlocks(Vec<(u32, H256)>),
}Expand description
Chain selection subsystem messages
Variants
Approved(H256)
Signal to the chain selection subsystem that a specific block has been approved.
Leaves(Sender<Vec<H256>>)
Request the leaves in descending order by score.
BestLeafContaining(H256, Sender<Option<H256>>)
Request the best leaf containing the given block in its ancestry. Return None if
there is no such leaf.
RevertBlocks(Vec<(u32, H256)>)
The passed blocks must be marked as reverted, and their children must be marked as non-viable.