Enum polkadot_node_subsystem::messages::CollatorProtocolMessage [−][src]
pub enum CollatorProtocolMessage {
CollateOn(Id),
DistributeCollation(CandidateReceipt<H256>, PoV, Option<Sender<CollationSecondedSignal>>),
ReportCollator(Public),
NetworkBridgeUpdateV1(NetworkBridgeEvent<CollatorProtocolMessage>),
Invalid(H256, CandidateReceipt<H256>),
Seconded(H256, Signed<Statement, CompactStatement>),
}Expand description
Messages received by the Collator Protocol subsystem.
Variants
CollateOn(Id)Signal to the collator protocol that it should connect to validators with the expectation of collating on the given para. This is only expected to be called once, early on, if at all, and only by the Collation Generation subsystem. As such, it will overwrite the value of the previous signal.
This should be sent before any DistributeCollation message.
Tuple Fields of CollateOn
0: IdDistributeCollation(CandidateReceipt<H256>, PoV, Option<Sender<CollationSecondedSignal>>)Provide a collation to distribute to validators with an optional result sender.
The result sender should be informed when at least one parachain validator seconded the collation. It is also completely okay to just drop the sender.
Tuple Fields of DistributeCollation
Report a collator as having provided an invalid collation. This should lead to disconnect and blacklist of the collator.
NetworkBridgeUpdateV1(NetworkBridgeEvent<CollatorProtocolMessage>)Get a network bridge update.
Tuple Fields of NetworkBridgeUpdateV1
Invalid(H256, CandidateReceipt<H256>)We recommended a particular candidate to be seconded, but it was invalid; penalize the collator.
The hash is the relay parent.
Tuple Fields of Invalid
0: H2561: CandidateReceipt<H256>Seconded(H256, Signed<Statement, CompactStatement>)The candidate we recommended to be seconded was validated successfully.
The hash is the relay parent.
Tuple Fields of Seconded
0: H2561: Signed<Statement, CompactStatement>Trait Implementations
Returns the relay parent this message is bound to.
Returns the “default value” for a type. Read more
Performs the conversion.
Performs the conversion.