Enum polkadot_node_subsystem::messages::NetworkBridgeMessage [−][src]
pub enum NetworkBridgeMessage {
ReportPeer(PeerId, UnifiedReputationChange),
DisconnectPeer(PeerId, PeerSet),
SendValidationMessage(Vec<PeerId, Global>, ValidationProtocol),
SendCollationMessage(Vec<PeerId, Global>, CollationProtocol),
SendValidationMessages(Vec<(Vec<PeerId, Global>, ValidationProtocol), Global>),
SendCollationMessages(Vec<(Vec<PeerId, Global>, CollationProtocol), Global>),
SendRequests(Vec<Requests, Global>, IfDisconnected),
ConnectToValidators {
validator_ids: Vec<Public, Global>,
peer_set: PeerSet,
failed: Sender<usize>,
},
ConnectToResolvedValidators {
validator_addrs: Vec<HashSet<Multiaddr, RandomState>, Global>,
peer_set: PeerSet,
},
NewGossipTopology {
our_neighbors: HashSet<Public, RandomState>,
},
}Expand description
Messages received by the network bridge subsystem.
Variants
ReportPeer(PeerId, UnifiedReputationChange)Report a peer for their actions.
Tuple Fields of ReportPeer
Disconnect a peer from the given peer-set without affecting their reputation.
SendValidationMessage(Vec<PeerId, Global>, ValidationProtocol)Send a message to one or more peers on the validation peer-set.
Tuple Fields of SendValidationMessage
0: Vec<PeerId, Global>1: ValidationProtocolSendCollationMessage(Vec<PeerId, Global>, CollationProtocol)Send a message to one or more peers on the collation peer-set.
Tuple Fields of SendCollationMessage
0: Vec<PeerId, Global>1: CollationProtocolSend a batch of validation messages.
NOTE: Messages will be processed in order (at least statement distribution relies on this).
Send a batch of collation messages.
NOTE: Messages will be processed in order.
SendRequests(Vec<Requests, Global>, IfDisconnected)Send requests via substrate request/response. Second parameter, tells what to do if we are not yet connected to the peer.
Tuple Fields of SendRequests
0: Vec<Requests, Global>1: IfDisconnectedConnect to peers who represent the given validator_ids.
Also ask the network to stay connected to these peers at least until a new request is issued.
Because it overrides the previous request, it must be ensured
that validator_ids include all peers the subsystems
are interested in (per PeerSet).
A caller can learn about validator connections by listening to the
PeerConnected events from the network bridge.
Fields of ConnectToValidators
Alternative to ConnectToValidators in case you already know the Multiaddrs you want to be
connected to.
Fields of ConnectToResolvedValidators
Inform the distribution subsystems about the new gossip network topology formed.
Fields of NewGossipTopology
our_neighbors: HashSet<Public, RandomState>Ids of our neighbors in the new gossip topology. We’re not necessarily connected to all of them, but we should.
Implementations
If the current variant contains the relay parent hash, return it.