pub enum StatementDistributionMessage {
Share(H256, Signed<StatementWithPVD, CompactStatement>),
Backed(CandidateHash),
NetworkBridgeUpdate(NetworkBridgeEvent<Versioned<StatementDistributionMessage, StatementDistributionMessage>>),
}Expand description
Statement distribution message.
Variants
We have originated a signed statement in the context of given relay-parent hash and it should be distributed to other validators.
Backed(CandidateHash)
The candidate received enough validity votes from the backing group.
If the candidate is backed as a result of a local statement, this message MUST
be preceded by a Share message for that statement. This ensures that Statement
Distribution is always aware of full candidates prior to receiving the Backed
notification, even when the group size is 1 and the candidate is seconded locally.
NetworkBridgeUpdate(NetworkBridgeEvent<Versioned<StatementDistributionMessage, StatementDistributionMessage>>)
Event from the network bridge.