Enum polkadot_node_subsystem::messages::network_bridge_event::NetworkBridgeEvent [−][src]
pub enum NetworkBridgeEvent<M> {
PeerConnected(PeerId, ObservedRole, Option<HashSet<Public, RandomState>>),
PeerDisconnected(PeerId),
NewGossipTopology(HashSet<PeerId, RandomState>),
PeerMessage(PeerId, M),
PeerViewChange(PeerId, View),
OurViewChange(OurView),
}Expand description
Events from network.
Variants
PeerConnected(PeerId, ObservedRole, Option<HashSet<Public, RandomState>>)A peer has connected.
Tuple Fields of PeerConnected
PeerDisconnected(PeerId)A peer has disconnected.
Tuple Fields of PeerDisconnected
0: PeerIdNewGossipTopology(HashSet<PeerId, RandomState>)Our neighbors in the new gossip topology. We’re not necessarily connected to all of them.
This message is issued only on the validation peer set.
Note, that the distribution subsystems need to handle the last view update of the newly added gossip peers manually.
Tuple Fields of NewGossipTopology
0: HashSet<PeerId, RandomState>PeerMessage(PeerId, M)Peer has sent a message.
Tuple Fields of PeerMessage
0: PeerId1: MPeer’s View has changed.
OurViewChange(OurView)Our view has changed.
Tuple Fields of OurViewChange
0: OurViewImplementations
pub fn focus<'a, T>(&'a self) -> Result<NetworkBridgeEvent<T>, WrongVariant> where
T: 'a + Clone,
&'a T: TryFrom<&'a M>,
<&'a T as TryFrom<&'a M>>::Error == WrongVariant,
pub fn focus<'a, T>(&'a self) -> Result<NetworkBridgeEvent<T>, WrongVariant> where
T: 'a + Clone,
&'a T: TryFrom<&'a M>,
<&'a T as TryFrom<&'a M>>::Error == WrongVariant,
Focus an overarching network-bridge event into some more specific variant.
This tries to transform M in PeerMessage to a message type specific to a subsystem.
It is used to dispatch events coming from a peer set to the various subsystems that are
handled within that peer set. More concretely a ValidationProtocol will be transformed
for example into a BitfieldDistributionMessage in case of the BitfieldDistribution
constructor.
Therefore a NetworkBridgeEvent<ValidationProtocol> will become for example a
NetworkBridgeEvent<BitfieldDistributionMessage>, with the more specific message type
BitfieldDistributionMessage.
This acts as a call to clone, except in the case where the event is a message event,
in which case the clone can be expensive and it only clones if the message type can
be focused.