pub enum CollatorProtocolMessage {
    CollateOn(Id),
    DistributeCollation(CandidateReceipt, H256, PoV, Option<Sender<CollationSecondedSignal>>),
    ReportCollator(Public),
    NetworkBridgeUpdate(NetworkBridgeEvent<Versioned<CollatorProtocolMessage, CollatorProtocolMessage>>),
    Invalid(H256, CandidateReceipt),
    Seconded(H256, Signed<Statement, CompactStatement>),
    Backed {
        para_id: Id,
        para_head: H256,
    },
}
Messages received by the Collator Protocol subsystem.

Variants



CollateOn(Id)

Signal to the collator protocol that it should connect to validators with the expectation of collating on the given para. This is only expected to be called once, early on, if at all, and only by the Collation Generation subsystem. As such, it will overwrite the value of the previous signal.

This should be sent before any DistributeCollation message.



DistributeCollation(CandidateReceipt, H256, PoV, Option<Sender<CollationSecondedSignal>>)

Provide a collation to distribute to validators with an optional result sender. The second argument is the parent head-data hash.

The result sender should be informed when at least one parachain validator seconded the collation. It is also completely okay to just drop the sender.



ReportCollator(Public)

Report a collator as having provided an invalid collation. This should lead to disconnect and blacklist of the collator.



NetworkBridgeUpdate(NetworkBridgeEvent<Versioned<CollatorProtocolMessage, CollatorProtocolMessage>>)

Get a network bridge update.



Invalid(H256, CandidateReceipt)

We recommended a particular candidate to be seconded, but it was invalid; penalize the collator.

The hash is the relay parent.



Seconded(H256, Signed<Statement, CompactStatement>)

The candidate we recommended to be seconded was validated successfully.

The hash is the relay parent.



Backed

Fields

para_id: Id

Candidate’s para id.

para_head: H256

Hash of the para head generated by candidate.

The candidate received enough validity votes from the backing group.